#!/usr/bin/env python3

import sys
import os

# Add the src directory to the Python path
sys.path.insert(0, os.path.join(os.path.dirname(os.path.abspath(__file__)), 'src'))

from alloy import parser

def test_exact_failure():
    # Exact code from the failing test
    exact_code = '''
        tool process_order takes order returns order_result {
            tax_amount = order + 0.08
            total = order + tax_amount
            order_result = {
                subtotal: order,
                tax: tax_amount,
                total: total
            }
        }
        result = process_order(100)
        '''
    
    print("=== Exact failing code ===")
    print(repr(exact_code))
    
    try:
        ast = parser.parse(exact_code)
        if ast and ast[0] == 'program' and len(ast) > 1:
            statements = ast[1]
            print(f"Success! Found {len(statements)} statements")
            for i, stmt in enumerate(statements):
                print(f"  Statement {i}: {stmt[0]}")
                if stmt[0] == 'tool':
                    tool_body = stmt[4]  # tool body is 5th element
                    if tool_body[0] == 'block':
                        tool_statements = tool_body[1]
                        print(f"    Tool body has {len(tool_statements)} statements:")
                        for j, tool_stmt in enumerate(tool_statements):
                            print(f"      {j}: {tool_stmt[0]} - {tool_stmt}")
        else:
            print("Failed to parse or no statements found")
            print("AST:", ast)
    except Exception as e:
        print(f"Parser error: {e}")
        import traceback
        traceback.print_exc()

    # Let's also test without the leading spaces
    clean_code = '''
tool process_order takes order returns order_result {
    tax_amount = order + 0.08
    total = order + tax_amount
    order_result = {
        subtotal: order,
        tax: tax_amount,
        total: total
    }
}
result = process_order(100)
'''
    
    print("\n=== Clean code (no leading spaces) ===")
    print(repr(clean_code))
    
    try:
        ast = parser.parse(clean_code)
        if ast and ast[0] == 'program' and len(ast) > 1:
            statements = ast[1]
            print(f"Success! Found {len(statements)} statements")
            for i, stmt in enumerate(statements):
                print(f"  Statement {i}: {stmt[0]}")
                if stmt[0] == 'tool':
                    tool_body = stmt[4]  # tool body is 5th element
                    if tool_body[0] == 'block':
                        tool_statements = tool_body[1]
                        print(f"    Tool body has {len(tool_statements)} statements:")
                        for j, tool_stmt in enumerate(tool_statements):
                            print(f"      {j}: {tool_stmt[0]} - {tool_stmt}")
        else:
            print("Failed to parse or no statements found")
            print("AST:", ast)
    except Exception as e:
        print(f"Parser error: {e}")
        import traceback
        traceback.print_exc()

if __name__ == "__main__":
    test_exact_failure()