#!/usr/bin/env python3

import sys
import os

# Add the src directory to the Python path
sys.path.insert(0, os.path.join(os.path.dirname(os.path.abspath(__file__)), 'src'))

from alloy import parser

def test_object_keys():
    
    tests = [
        # Test different object structures
        ("Single key", '''
tool test takes order returns result {
    tax_amount = order + 0.08
    total = order + tax_amount
    result = {
        total: total
    }
}'''),
        
        ("Two keys", '''
tool test takes order returns result {
    tax_amount = order + 0.08
    total = order + tax_amount
    result = {
        tax: tax_amount,
        total: total
    }
}'''),
        
        ("Three keys (exact failing)", '''
tool test takes order returns result {
    tax_amount = order + 0.08
    total = order + tax_amount
    result = {
        subtotal: order,
        tax: tax_amount,
        total: total
    }
}'''),
        
        ("Three keys with different names", '''
tool test takes order returns result {
    tax_amount = order + 0.08
    total = order + tax_amount
    result = {
        a: order,
        b: tax_amount,
        c: total
    }
}'''),
        
        ("Three keys with 'subtotal' key", '''
tool test takes order returns result {
    tax_amount = order + 0.08
    total = order + tax_amount
    result = {
        subtotal: order,
        b: tax_amount,
        c: total
    }
}'''),
    ]
    
    for name, code in tests:
        print(f"=== {name} ===")
        print(repr(code))
        
        try:
            ast = parser.parse(code)
            if ast and ast[0] == 'program' and len(ast) > 1:
                statements = ast[1]
                if len(statements) > 0 and statements[0][0] == 'tool':
                    tool_body = statements[0][4]
                    if tool_body[0] == 'block':
                        tool_statements = tool_body[1]
                        print(f"SUCCESS: Tool body has {len(tool_statements)} statements")
                    else:
                        print(f"ERROR: Tool body is not a block: {tool_body}")
                else:
                    print(f"ERROR: No tool statement found. Found {len(statements)} statements of types: {[s[0] for s in statements]}")
            else:
                print("ERROR: Failed to parse or no statements found")
                print("AST:", ast)
        except Exception as e:
            print(f"PARSER ERROR: {e}")
        
        print()

if __name__ == "__main__":
    test_object_keys()