#!/usr/bin/env python3

import sys
import os

# Add the src directory to the Python path
sys.path.insert(0, os.path.join(os.path.dirname(os.path.abspath(__file__)), 'src'))

from alloy import parser

def test_statement_count():
    
    tests = [
        ("1 statement - object", '''
tool test takes x returns result {
    result = {a: x}
}'''),
        
        ("2 statements - simple + object", '''
tool test takes x returns result {
    a = x + 1
    result = {a: a}
}'''),
        
        ("3 statements - simple + simple + object", '''
tool test takes x returns result {
    a = x + 1
    b = a + 1
    result = {a: a}
}'''),
        
        ("3 statements - all simple", '''
tool test takes x returns result {
    a = x + 1
    b = a + 1
    result = b + 1
}'''),
        
        ("4 statements - 3 simple + object", '''
tool test takes x returns result {
    a = x + 1
    b = a + 1
    c = b + 1
    result = {a: a}
}'''),
    ]
    
    for name, code in tests:
        print(f"=== {name} ===")
        print(repr(code))
        
        try:
            ast = parser.parse(code)
            if ast and ast[0] == 'program' and len(ast) > 1:
                statements = ast[1]
                if len(statements) > 0 and statements[0][0] == 'tool':
                    tool_body = statements[0][4]
                    if tool_body[0] == 'block':
                        tool_statements = tool_body[1]
                        print(f"SUCCESS: Tool body has {len(tool_statements)} statements")
                    else:
                        print(f"ERROR: Tool body is not a block: {tool_body}")
                else:
                    print(f"ERROR: No tool statement found. Found {len(statements)} statements of types: {[s[0] for s in statements]}")
            else:
                print("ERROR: Failed to parse or no statements found")
        except Exception as e:
            print(f"PARSER ERROR: {e}")
        
        print()

if __name__ == "__main__":
    test_statement_count()