#!/usr/bin/env python3

import sys
import os

# Add the src directory to the Python path
sys.path.insert(0, os.path.join(os.path.dirname(os.path.abspath(__file__)), 'src'))

from alloy import parser

def test_incremental():
    
    tests = [
        # Start simple and build up
        ("Empty tool", '''
tool test takes x returns result {
}
'''),
        
        ("One assignment", '''
tool test takes x returns result {
    result = x
}
'''),
        
        ("Two assignments", '''
tool test takes x returns result {
    a = x
    result = a
}
'''),
        
        ("Two assignments with addition", '''
tool test takes x returns result {
    a = x + 1
    result = a
}
'''),
        
        ("Two assignments with binary operation", '''
tool test takes x returns result {
    a = x + 1
    result = x + a
}
'''),
        
        ("The exact failing pattern", '''
tool test takes x returns result {
    a = x + 1
    b = x + a
    result = {key: b}
}
'''),
    ]
    
    for name, code in tests:
        print(f"=== {name} ===")
        print(repr(code))
        
        try:
            ast = parser.parse(code)
            if ast and ast[0] == 'program' and len(ast) > 1:
                statements = ast[1]
                if len(statements) > 0 and statements[0][0] == 'tool':
                    tool_body = statements[0][4]
                    if tool_body[0] == 'block':
                        tool_statements = tool_body[1]
                        print(f"SUCCESS: Tool body has {len(tool_statements)} statements")
                    else:
                        print(f"ERROR: Tool body is not a block")
                else:
                    print(f"ERROR: No tool statement found")
            else:
                print("ERROR: Failed to parse")
                print("AST:", ast)
        except Exception as e:
            print(f"PARSER ERROR: {e}")
        
        print()

if __name__ == "__main__":
    test_incremental()